==> apache-camel-4.0.1-src.zip: apache-camel-4.0.1/components/camel-quartz/src/test/java/org/apache/camel/component/quartz/QuartzOneCamelContextSuspendResumeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.quartz;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.impl.DefaultCamelContext;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class QuartzOneCamelContextSuspendResumeTest {

    private DefaultCamelContext camel1;

    @BeforeEach
    public void setUp() throws Exception {
        camel1 = new DefaultCamelContext();
        camel1.addRoutes(new RouteBuilder() {
            @Override
            public void configure() {
                from("quartz://myGroup/myTimerName?cron=0/1+*+*+*+*+?").to("mock:one");
            }
        });
        camel1.start();
    }

    @AfterEach
    public void tearDown() {
        camel1.stop();
    }

    @Test
    public void testOneCamelContextSuspendResume() throws Exception {
        MockEndpoint mock1 = camel1.getEndpoint("mock:one", MockEndpoint.class);
        mock1.expectedMinimumMessageCount(2);
        mock1.assertIsSatisfied();

        camel1.suspend();

        // should resume triggers when we start camel 1 again
        mock1.reset();
        mock1.expectedMinimumMessageCount(2);
        camel1.resume();

        mock1.assertIsSatisfied();
    }

}

==> apache-camel-4.14.5-src.zip: apache-camel-4.14.5/components/camel-quartz/src/test/java/org/apache/camel/component/quartz/QuartzOneCamelContextSuspendResumeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.quartz;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.impl.DefaultCamelContext;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;

public class QuartzOneCamelContextSuspendResumeTest {

    private DefaultCamelContext camel1;

    @BeforeEach
    public void setUp() throws Exception {
        camel1 = new DefaultCamelContext();
        camel1.addRoutes(new RouteBuilder() {
            @Override
            public void configure() {
                from("quartz://myGroup/myTimerName?cron=0/1+*+*+*+*+?").to("mock:one");
            }
        });
        camel1.start();
    }

    @AfterEach
    public void tearDown() {
        camel1.stop();
    }

    @Test
    public void testOneCamelContextSuspendResume() throws Exception {
        MockEndpoint mock1 = camel1.getEndpoint("mock:one", MockEndpoint.class);
        mock1.expectedMinimumMessageCount(2);
        mock1.assertIsSatisfied();

        assertDoesNotThrow(() -> camel1.suspend());

        // should resume triggers when we start camel 1 again
        mock1.reset();
        mock1.expectedMinimumMessageCount(2);
        assertDoesNotThrow(() -> camel1.resume());

        mock1.assertIsSatisfied();
    }

}
